@@ -9,8 +9,8 @@ class Project(AbstractApiClass):
             client (ApiClient): An authenticated API Client instance
             projectId (str): The ID of the project.
             name (str): The name of the project.
-            useCase (str): The  Use Case associated with the project.
-            problemType (str): 
+            useCase (str): The use case associated with the project.
+            problemType (str): The problem type associated with the project.
             createdAt (str): The date and time when the project was created.
             featureGroupsEnabled (bool): Project uses feature groups instead of datasets.
     """
@@ -246,7 +246,7 @@ class Project(AbstractApiClass):
             custom_algorithms (list): List of user-defined algorithms to train. If not set, will run default enabled custom algorithms.
             custom_algorithms_only (bool): Whether only run custom algorithms.
             custom_algorithm_configs (dict): Configs for each user-defined algorithm, key is algorithm name, value is the config serialized to json
-            builtin_algorithms (list): List of the builtin algorithms provided by Abacus.AI to train. If not set, will try all applicable builtin algorithms.
+            builtin_algorithms (list): List of ids of the builtin algorithms provided by Abacus.AI to train. If not set, will try all applicable builtin algorithms.
             cpu_size (str): Size of the cpu for the user-defined algorithms during train.
             memory (int): Memory (in GB) for the user-defined algorithms during train.
 
@@ -255,7 +255,7 @@ class Project(AbstractApiClass):
         """
         return self.client.train_model(self.project_id, name, training_config, feature_group_ids, refresh_schedule, custom_algorithms, custom_algorithms_only, custom_algorithm_configs, builtin_algorithms, cpu_size, memory)
 
-    def create_model_from_python(self, function_source_code: str, train_function_name: str, training_input_tables: list, predict_function_name: str = None, predict_many_function_name: str = None, initialize_function_name: str = None, name: str = None, cpu_size: str = None, memory: int = None, training_config: dict = None, exclusive_run: bool = False, package_requirements: dict = None):
+    def create_model_from_python(self, function_source_code: str, train_function_name: str, training_input_tables: list, predict_function_name: str = None, predict_many_function_name: str = None, initialize_function_name: str = None, name: str = None, cpu_size: str = None, memory: int = None, training_config: dict = None, exclusive_run: bool = False, package_requirements: list = None):
         """
         Initializes a new Model from user provided Python code. If a list of input feature groups are supplied,
 
@@ -280,7 +280,7 @@ class Project(AbstractApiClass):
             memory (int): Memory (in GB) for the model training function
             training_config (dict): Training configuration
             exclusive_run (bool): Decides if this model will be run exclusively OR along with other Abacus.ai algorithms
-            package_requirements (dict): Json with key value pairs corresponding to package: version for each dependency
+            package_requirements (list): List of package requirement strings. For example: ['numpy==1.2.3', 'pandas>=1.4.0']
 
         Returns:
             Model: The new model, which has not been trained.
@@ -314,7 +314,7 @@ class Project(AbstractApiClass):
         """
         return self.client.get_custom_train_function_info(self.project_id, feature_group_names_for_training, training_data_parameter_name_override, training_config, custom_algorithm_config)
 
-    def create_model_monitor(self, prediction_feature_group_id: str, training_feature_group_id: str = None, name: str = None, refresh_schedule: str = None, target_value: str = None, target_value_bias: str = None, target_value_performance: str = None, feature_mappings: dict = None, model_id: str = None, training_feature_mappings: dict = None, feature_group_base_monitor_config: dict = None, feature_group_comparison_monitor_config: dict = None):
+    def create_model_monitor(self, prediction_feature_group_id: str, training_feature_group_id: str = None, name: str = None, refresh_schedule: str = None, target_value: str = None, target_value_bias: str = None, target_value_performance: str = None, feature_mappings: dict = None, model_id: str = None, training_feature_mappings: dict = None, feature_group_base_monitor_config: dict = None, feature_group_comparison_monitor_config: dict = None, img_url_prefixes: dict = None):
         """
         Runs a model monitor for the specified project.
 
@@ -329,13 +329,14 @@ class Project(AbstractApiClass):
             feature_mappings (dict): A json map to override features for prediction_feature_group, where keys are column names and the values are feature data use types.
             model_id (str): The Unique ID of the Model
             training_feature_mappings (dict): A json map to override features for training_fature_group, where keys are column names and the values are feature data use types.
-            feature_group_base_monitor_config (dict): 
-            feature_group_comparison_monitor_config (dict): 
+            feature_group_base_monitor_config (dict): selection startegy for the feature_group 1 with the feature group version if selected
+            feature_group_comparison_monitor_config (dict): selection startegy for the feature_group 1 with the feature group version if selected
+            img_url_prefixes (dict): 
 
         Returns:
             ModelMonitor: The new model monitor that was created.
         """
-        return self.client.create_model_monitor(self.project_id, prediction_feature_group_id, training_feature_group_id, name, refresh_schedule, target_value, target_value_bias, target_value_performance, feature_mappings, model_id, training_feature_mappings, feature_group_base_monitor_config, feature_group_comparison_monitor_config)
+        return self.client.create_model_monitor(self.project_id, prediction_feature_group_id, training_feature_group_id, name, refresh_schedule, target_value, target_value_bias, target_value_performance, feature_mappings, model_id, training_feature_mappings, feature_group_base_monitor_config, feature_group_comparison_monitor_config, img_url_prefixes)
 
     def list_model_monitors(self):
         """
@@ -349,6 +350,55 @@ class Project(AbstractApiClass):
         """
         return self.client.list_model_monitors(self.project_id)
 
+    def create_vision_drift_monitor(self, prediction_feature_group_id: str, training_feature_group_id: str, name: str, feature_mappings: dict, training_feature_mappings: dict, target_value_performance: str = None, refresh_schedule: str = None):
+        """
+        Runs a vision drift monitor for the specified project.
+
+        Args:
+            prediction_feature_group_id (str): The unique ID of the prediction data feature group
+            training_feature_group_id (str): The unique ID of the training data feature group
+            name (str): The name you want your model monitor to have. Defaults to "<Project Name> Model Monitor".
+            feature_mappings (dict): A json map to override features for prediction_feature_group, where keys are column names and the values are feature data use types.
+            training_feature_mappings (dict): A json map to override features for training_fature_group, where keys are column names and the values are feature data use types.
+            target_value_performance (str): A target positive value for the label to compute pr curve/ auc for performance page
+            refresh_schedule (str): A cron-style string that describes a schedule in UTC to automatically retrain the created vision drift monitor
+
+        Returns:
+            ModelMonitor: The new model monitor that was created.
+        """
+        return self.client.create_vision_drift_monitor(self.project_id, prediction_feature_group_id, training_feature_group_id, name, feature_mappings, training_feature_mappings, target_value_performance, refresh_schedule)
+
+    def create_eda(self, feature_group_id: str, name: str, refresh_schedule: str = None, include_collinearity: bool = False, include_data_consistency: bool = False, primary_keys: list = None, data_consistency_test_config: dict = None, data_consistency_reference_config: dict = None):
+        """
+        Runs an eda (exploratory data analysis) for the specified project.
+
+        Args:
+            feature_group_id (str): The unique ID of the prediction data feature group
+            name (str): The name you want your model monitor to have. Defaults to "<Project Name> EDA".
+            refresh_schedule (str): A cron-style string that describes a schedule in UTC to automatically retrain the created EDA
+            include_collinearity (bool): Set to True if the eda type is collinearity
+            include_data_consistency (bool): Set to True if the eda type is Data consistency
+            primary_keys (list): List of features that corresponds to the primary keys for the given feature group for Data Consistency analysis
+            data_consistency_test_config (dict): Test feature group version selection strategy for Data Consistency eda type
+            data_consistency_reference_config (dict): Reference (Control) feature group version selection strategy for Data Consistency eda type
+
+        Returns:
+            ModelMonitor: The new model monitor that was created.
+        """
+        return self.client.create_eda(self.project_id, feature_group_id, name, refresh_schedule, include_collinearity, include_data_consistency, primary_keys, data_consistency_test_config, data_consistency_reference_config)
+
+    def list_eda(self):
+        """
+        Retrieves the list of EDA (exploratory data analysis) in the specified project.
+
+        Args:
+            project_id (str): The unique ID associated with the project.
+
+        Returns:
+            ModelMonitor: An array of model monitors.
+        """
+        return self.client.list_eda(self.project_id)
+
     def create_monitor_alert(self, model_monitor_id: str, alert_name: str, condition_config: dict, action_config: dict):
         """
         Create a monitor alert for the given conditions and monitor
@@ -432,6 +482,31 @@ class Project(AbstractApiClass):
         """
         return self.client.list_batch_predictions(self.project_id)
 
+    def create_graph_dashboard(self, name: str, python_function_ids: list):
+        """
+        Create a plot dashboard given selected python plots
+
+        Args:
+            name (str): The name of the dashboard
+            python_function_ids (list): The list of python function ids to use in the graph dashboard
+
+        Returns:
+            GraphDashboard: An object describing the graph dashboard
+        """
+        return self.client.create_graph_dashboard(self.project_id, name, python_function_ids)
+
+    def list_graph_dashboards(self):
+        """
+        Lists the graph dashboards for a project
+
+        Args:
+            project_id (str): The project id to list graph dashboards
+
+        Returns:
+            GraphDashboard: An aray of graph dashboards
+        """
+        return self.client.list_graph_dashboards(self.project_id)
+
     def list_builtin_algorithms(self, feature_group_ids: list = None, training_config: dict = None):
         """
         Return list of builtin algorithms based on given input.
